@@ -3,7 +3,7 @@
 using namespace Rcpp;
 using namespace std;
 
-void Update::update_gamma(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_gamma(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	double alt_gamma_lik = likelihood.get_gamma_lik(!in_state.gamma) / temperature;
 	double alt_alpha_star_lik = likelihood.get_alpha_star_lik(in_state.alpha_star, !in_state.gamma) / temperature;
 	double alt_alpha_lik = likelihood.get_alpha_lik(in_state.alpha, !in_state.gamma) / temperature;
@@ -13,7 +13,7 @@ void Update::update_gamma(State& in_state, Likelihood& likelihood, double temper
 	double alt_log_alpha_plus_beta_f_lik = likelihood.get_log_alpha_plus_beta_f_lik(in_state.log_alpha_plus_beta_f, !in_state.gamma) / temperature;
 	double alt_logit_mean_g_lik = likelihood.get_logit_mean_g_lik(in_state.logit_mean_g, !in_state.gamma) / temperature;
 	double alt_log_alpha_plus_beta_g_lik = likelihood.get_log_alpha_plus_beta_g_lik(in_state.log_alpha_plus_beta_g, !in_state.gamma) / temperature;
-	double alt_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise), d.g, in_state.alpha_star, in_state.alpha, in_state.log_beta, !in_state.gamma) / temperature;
+	double alt_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d), d.g, in_state.alpha_star, in_state.alpha, in_state.log_beta, !in_state.gamma) / temperature;
 
 	double alt_total_lik = 
 		alt_gamma_lik +
@@ -56,7 +56,7 @@ void Update::update_gamma(State& in_state, Likelihood& likelihood, double temper
 	}
 }
 
-void Update::update_alpha_star(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_alpha_star(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {
 		in_state.alpha_star = norm_rand() * likelihood.pseudo_alpha_star_sd + likelihood.pseudo_alpha_star_mean;
 		in_state.cur_alpha_star_lik = in_state.get_alpha_star_lik(likelihood);
@@ -66,9 +66,9 @@ void Update::update_alpha_star(State& in_state, Likelihood& likelihood, double t
 		
 		double proposed_alpha_star_lik = likelihood.get_alpha_star_lik(proposed_alpha_star, in_state.gamma) / temperature;
 		
-		double proposed_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise), d.g, proposed_alpha_star, in_state.alpha, in_state.log_beta, in_state.gamma) / temperature;
+		double proposed_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d), d.g, proposed_alpha_star, in_state.alpha, in_state.log_beta, in_state.gamma) / temperature;
 
-		if (log(unif_rand()) < (proposed_alpha_star_lik + proposed_y_lik - (in_state.get_alpha_star_lik(likelihood, temperature) + in_state.get_y_lik(likelihood, ttsm, row_is_column_anc, d, temperature, reparameterise, quantile_normalise)))) {
+		if (log(unif_rand()) < (proposed_alpha_star_lik + proposed_y_lik - (in_state.get_alpha_star_lik(likelihood, temperature) + in_state.get_y_lik(likelihood, ttsm, row_is_column_anc, d, temperature)))) {
 			in_state.alpha_star = proposed_alpha_star;
 			in_state.cur_alpha_star_lik = proposed_alpha_star_lik;
 			in_state.cur_y_lik = proposed_y_lik;
@@ -76,15 +76,15 @@ void Update::update_alpha_star(State& in_state, Likelihood& likelihood, double t
 	}
 }
 
-void Update::update_alpha(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_alpha(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {
 		double proposed_alpha = in_state.alpha + norm_rand() * alpha_proposal_sd;
 		
 		double proposed_alpha_lik = likelihood.get_alpha_lik(proposed_alpha, in_state.gamma) / temperature;
 		
-		double proposed_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise), d.g, in_state.alpha_star, proposed_alpha, in_state.log_beta, in_state.gamma) / temperature;
+		double proposed_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d), d.g, in_state.alpha_star, proposed_alpha, in_state.log_beta, in_state.gamma) / temperature;
 
-		if (log(unif_rand()) < ((proposed_alpha_lik + proposed_y_lik) - (in_state.get_alpha_lik(likelihood, temperature) + in_state.get_y_lik(likelihood, ttsm, row_is_column_anc, d, temperature, reparameterise, quantile_normalise)))) {
+		if (log(unif_rand()) < ((proposed_alpha_lik + proposed_y_lik) - (in_state.get_alpha_lik(likelihood, temperature) + in_state.get_y_lik(likelihood, ttsm, row_is_column_anc, d, temperature)))) {
 			in_state.alpha = proposed_alpha;
 			in_state.cur_alpha_lik = proposed_alpha_lik;
 			in_state.cur_y_lik = proposed_y_lik;
@@ -96,16 +96,16 @@ void Update::update_alpha(State& in_state, Likelihood& likelihood, double temper
 	}
 }
 
-void Update::update_log_beta(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_log_beta(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {
 		double current_log_beta_lik = in_state.get_log_beta_lik(likelihood, temperature);
-		double current_y_lik = in_state.get_y_lik(likelihood, ttsm, row_is_column_anc, d, temperature, reparameterise, quantile_normalise);
+		double current_y_lik = in_state.get_y_lik(likelihood, ttsm, row_is_column_anc, d, temperature);
 	
 		double proposed_log_beta = in_state.log_beta + norm_rand() * log_beta_proposal_sd;
 		
 		double proposed_log_beta_lik = likelihood.get_log_beta_lik(proposed_log_beta, in_state.gamma) / temperature;
 		
-		double proposed_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise), d.g, in_state.alpha_star, in_state.alpha, proposed_log_beta, in_state.gamma) / temperature;
+		double proposed_y_lik = likelihood.get_y_lik(d.y, in_state.get_x(ttsm, row_is_column_anc, d), d.g, in_state.alpha_star, in_state.alpha, proposed_log_beta, in_state.gamma) / temperature;
 
 		if (log(unif_rand()) < ((proposed_log_beta_lik + proposed_y_lik) - (current_log_beta_lik + current_y_lik))) {
 			in_state.log_beta = proposed_log_beta;
@@ -118,7 +118,7 @@ void Update::update_log_beta(State& in_state, Likelihood& likelihood, double tem
 	}
 }
 
-void Update::update_phi_and_inflexion(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_phi_and_inflexion(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {	
 		IntegerVector phi_proposed(in_state.phi.length());
 		double proposed_logit_mean_f = in_state.logit_mean_f + norm_rand() * logit_mean_f_proposal_sd;
@@ -142,8 +142,7 @@ void Update::update_phi_and_inflexion(State& in_state, Likelihood& likelihood, d
 			row_is_column_anc,
 			ttsm,
 			phi_proposed,
-			d.h, 
-			quantile_normalise
+			d.h
 		);
 
 		NumericVector prop_x = transform_each_way_sim(
@@ -151,8 +150,7 @@ void Update::update_phi_and_inflexion(State& in_state, Likelihood& likelihood, d
 			proposed_logit_mean_f,
 			in_state.log_alpha_plus_beta_f,
 			proposed_logit_mean_g,
-			in_state.log_alpha_plus_beta_g,
-			reparameterise
+			in_state.log_alpha_plus_beta_g
 		);
 
 		double proposed_y_lik = likelihood.get_y_lik(
@@ -201,13 +199,13 @@ void Update::update_phi_and_inflexion(State& in_state, Likelihood& likelihood, d
 			in_state.cur_logit_mean_f_lik = in_state.get_logit_mean_f_lik(likelihood);
 			in_state.cur_logit_mean_g_lik = in_state.get_logit_mean_g_lik(likelihood);
 
-			in_state._s = in_state.get_s(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
-			in_state._x = in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
+			in_state._s = in_state.get_s(ttsm, row_is_column_anc, d);
+			in_state._x = in_state.get_x(ttsm, row_is_column_anc, d);
 
 	}
 }
 
-void Update::update_phi(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_phi(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {	
 		IntegerVector phi_proposed(in_state.phi.length());
 
@@ -227,8 +225,7 @@ void Update::update_phi(State& in_state, Likelihood& likelihood, double temperat
 			row_is_column_anc,
 			ttsm,
 			phi_proposed,
-			d.h, 
-			quantile_normalise
+			d.h
 		);
 
 		NumericVector prop_x = transform_each_way_sim(
@@ -236,8 +233,7 @@ void Update::update_phi(State& in_state, Likelihood& likelihood, double temperat
 			in_state.logit_mean_f,
 			in_state.log_alpha_plus_beta_f,
 			in_state.logit_mean_g,
-			in_state.log_alpha_plus_beta_g,
-			reparameterise
+			in_state.log_alpha_plus_beta_g
 		);
 
 		double proposed_y_lik = likelihood.get_y_lik(
@@ -274,12 +270,12 @@ void Update::update_phi(State& in_state, Likelihood& likelihood, double temperat
 			in_state.phi[k] = likelihood.pseudo_phi_marginal_prior[random_integer(likelihood.pseudo_phi_marginal_prior.length())];
 			in_state.cur_phi_lik = in_state.get_phi_lik(likelihood);
 
-			in_state._s = in_state.get_s(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
-			in_state._x = in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
+			in_state._s = in_state.get_s(ttsm, row_is_column_anc, d);
+			in_state._x = in_state.get_x(ttsm, row_is_column_anc, d);
 	}
 }
 
-void Update::update_logit_mean_f(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_logit_mean_f(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {
 		double proposed_logit_mean_f = in_state.logit_mean_f + norm_rand() * logit_mean_f_proposal_sd;
 		
@@ -290,8 +286,7 @@ void Update::update_logit_mean_f(State& in_state, Likelihood& likelihood, double
 			proposed_logit_mean_f,
 			in_state.log_alpha_plus_beta_f,
 			in_state.logit_mean_g,
-			in_state.log_alpha_plus_beta_g,
-			reparameterise
+			in_state.log_alpha_plus_beta_g
 		);
 		
 		double proposed_y_lik = likelihood.get_y_lik(d.y, x_proposed, d.g, in_state.alpha_star, in_state.alpha, in_state.log_beta, in_state.gamma) / temperature;
@@ -305,11 +300,11 @@ void Update::update_logit_mean_f(State& in_state, Likelihood& likelihood, double
 	} else {
 		in_state.logit_mean_f = norm_rand() * likelihood.pseudo_logit_mean_f_sd + likelihood.pseudo_logit_mean_f_mean;
 		in_state.cur_logit_mean_f_lik = in_state.get_logit_mean_f_lik(likelihood);
-		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
+		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d);
 	}
 }
 
-void Update::update_log_alpha_plus_beta_f(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_log_alpha_plus_beta_f(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {
 		double proposed_log_alpha_plus_beta_f = in_state.log_alpha_plus_beta_f + norm_rand() * log_alpha_plus_beta_f_proposal_sd;
 		
@@ -320,8 +315,7 @@ void Update::update_log_alpha_plus_beta_f(State& in_state, Likelihood& likelihoo
 			in_state.logit_mean_f,
 			proposed_log_alpha_plus_beta_f,
 			in_state.logit_mean_g,
-			in_state.log_alpha_plus_beta_g,
-			reparameterise
+			in_state.log_alpha_plus_beta_g
 		);
 		
 		double proposed_y_lik = likelihood.get_y_lik(d.y, x_proposed, d.g, in_state.alpha_star, in_state.alpha, in_state.log_beta, in_state.gamma) / temperature;
@@ -335,11 +329,11 @@ void Update::update_log_alpha_plus_beta_f(State& in_state, Likelihood& likelihoo
 	} else {
 		in_state.log_alpha_plus_beta_f = norm_rand() * likelihood.pseudo_log_alpha_plus_beta_f_sd + likelihood.pseudo_log_alpha_plus_beta_f_mean;
 		in_state.cur_log_alpha_plus_beta_f_lik = in_state.get_log_alpha_plus_beta_f_lik(likelihood);
-		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
+		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d);
 	}
 }
 
-void Update::update_logit_mean_g(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_logit_mean_g(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {
 		double proposed_logit_mean_g = in_state.logit_mean_g + norm_rand() * logit_mean_g_proposal_sd;
 		
@@ -350,8 +344,7 @@ void Update::update_logit_mean_g(State& in_state, Likelihood& likelihood, double
 			in_state.logit_mean_f,
 			in_state.log_alpha_plus_beta_f,
 			proposed_logit_mean_g,
-			in_state.log_alpha_plus_beta_g,
-			reparameterise
+			in_state.log_alpha_plus_beta_g
 		);
 		
 		double proposed_y_lik = likelihood.get_y_lik(d.y, x_proposed, d.g, in_state.alpha_star, in_state.alpha, in_state.log_beta, in_state.gamma) / temperature;
@@ -365,11 +358,11 @@ void Update::update_logit_mean_g(State& in_state, Likelihood& likelihood, double
 	} else {
 		in_state.logit_mean_g = norm_rand() * likelihood.pseudo_logit_mean_g_sd + likelihood.pseudo_logit_mean_g_mean;
 		in_state.cur_logit_mean_g_lik = in_state.get_logit_mean_g_lik(likelihood);
-		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
+		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d);
 	}
 }
 
-void Update::update_log_alpha_plus_beta_g(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool reparameterise, bool quantile_normalise) {
+void Update::update_log_alpha_plus_beta_g(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm) {
 	if (in_state.gamma) {
 		double proposed_log_alpha_plus_beta_g = in_state.log_alpha_plus_beta_g + norm_rand() * log_alpha_plus_beta_g_proposal_sd;
 		
@@ -380,8 +373,7 @@ void Update::update_log_alpha_plus_beta_g(State& in_state, Likelihood& likelihoo
 			in_state.logit_mean_f,
 			in_state.log_alpha_plus_beta_f,
 			in_state.logit_mean_g,
-			proposed_log_alpha_plus_beta_g,
-			reparameterise
+			proposed_log_alpha_plus_beta_g
 		);
 		
 		double proposed_y_lik = likelihood.get_y_lik(d.y, x_proposed, d.g, in_state.alpha_star, in_state.alpha, in_state.log_beta, in_state.gamma) / temperature;
@@ -395,29 +387,28 @@ void Update::update_log_alpha_plus_beta_g(State& in_state, Likelihood& likelihoo
 	} else {
 		in_state.log_alpha_plus_beta_g = norm_rand() * likelihood.pseudo_log_alpha_plus_beta_g_sd + likelihood.pseudo_log_alpha_plus_beta_g_mean;
 		in_state.cur_log_alpha_plus_beta_g_lik = in_state.get_log_alpha_plus_beta_g_lik(likelihood);
-		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d, reparameterise, quantile_normalise);
+		in_state._x = in_state.get_x(ttsm, row_is_column_anc, d);
 	}
 }
 
-void Update::update(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool fix_phi, bool reparameterise, bool quantile_normalise) {
-	update_alpha_star(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-	update_alpha(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-	update_log_beta(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-	update_logit_mean_f(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-	update_log_alpha_plus_beta_f(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-	update_logit_mean_g(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-	update_log_alpha_plus_beta_g(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
+void Update::update(State& in_state, Likelihood& likelihood, double temperature, Data& d, LogicalMatrix row_is_column_anc, NumericMatrix ttsm, bool fix_phi) {
+	update_gamma(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+	update_alpha_star(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+	update_alpha(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+	update_log_beta(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+	update_logit_mean_f(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+	update_log_alpha_plus_beta_f(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+	update_logit_mean_g(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+	update_log_alpha_plus_beta_g(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
 
 	if (joint_proposal) {
-		update_phi_and_inflexion(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
+		update_phi_and_inflexion(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
 	}
 	else {
-		update_logit_mean_g(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-		update_logit_mean_f(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
-		if (!fix_phi) update_phi(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
+		update_logit_mean_g(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+		update_logit_mean_f(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
+		if (!fix_phi) update_phi(in_state, likelihood, temperature, d, row_is_column_anc, ttsm);
 	}
-
-	update_gamma(in_state, likelihood, temperature, d, row_is_column_anc, ttsm, reparameterise, quantile_normalise);
 }
 
 
